
class DynArray:
    pass

class DynArray:
    def __init__(self):
        self.__data = []

    def append(self, element: any) -> None:
        self.__data.append(element)

    def delete(self, index: int) -> None:
        del self.__data[index]

    def insertAT(self, index: int, element: any) -> None:
        self.__data.insert(index, element)

    def getItem(self, index: int) -> any:
        return self.__data[index]

    def setItem(self, index: int, element: any) -> None:
        self.__data[index] = element

    def isEmpty(self) -> bool:
        return len(self.__data) == 0

    def getLength(self) -> int:
        return len(self.__data)
    
    # convinience constructor methods
    @classmethod
    def from_list(cls, l: list) -> DynArray:
        s = cls()
        for el in l:
            s.append(el)
        return s

    @classmethod
    def from_elements(cls, *args: any) -> DynArray:
        s = cls()
        for el in args:
            s.append(el)
        return s




class Stack:
    pass

class Stack:
    def __init__(self) -> None:
        self.__data = []

    def isEmpty(self) -> bool:
        return len(self.__data) == 0

    def top(self) -> any:
        if len(self.__data) < 1:
            return None
        return self.__data[-1]

    def push(self, element: any) -> None:
        self.__data.append(element)

    def pop(self) -> any:
        return self.__data.pop()
    
    # convinience constructor methods
    @classmethod
    def from_string(cls, string: str) -> Stack:
        s = cls()
        for char in string:
            s.push(char)
        return s

    @classmethod
    def from_list(cls, l: list) -> Stack:
        s = cls()
        for el in l:
            s.push(el)
        return s

    @classmethod
    def from_elements(cls, *args: any) -> Stack:
        s = cls()
        for el in args:
            s.push(el)
        return s





class Queue:
    def __init__(self) -> None:
        self.__data = []

    def isEmpty(self) -> bool:
        return len(self.__data) == 0

    def head(self) -> any:
        return self.__data[0]

    def enqueue(self, element: any) -> None:
        self.__data.append(element)

    def dequeue(self) -> any:
        return self.__data.pop(0)





class BinTree:
    pass

class BinTree:
    def __init__(self, inhalt: any = None) -> None:
        self.__value = inhalt
        self.__left = None
        self.__right = None

    def hasItem(self) -> bool:
        return self.__value is not None

    def setItem(self, inhalt: any) -> None:
        self.__value = inhalt

    def deleteItem(self) -> None:
        self.__value = None

    def isLeaf(self) -> bool:
        return (self.__right is None) and (self.__left is None)

    def hasLeft(self) -> bool:
        return self.__left is not None

    def getLeft(self) -> BinTree:
        return self.__left

    def setLeft(self, b: BinTree) -> None:
        self.__left = b

    def deleteLeft(self) -> None:
        self.__left = None

    def hasRight(self) -> bool:
        return self.__right is not None

    def getRight(self) -> BinTree:
        return self.__right

    def setRight(self, b: BinTree) -> None:
        self.__right = b

    def deleteRight(self) -> None:
        self.__right = None





from setuptools import setup, find_packages

from codecs import open
from os import path

HERE = path.abspath(path.dirname(__file__))

with open(path.join(HERE, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="cs-nds",
    version="0.3.0",
    description="Often used things for Computer Science classes",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/alexcoder04/cs_nds",
    author="alexcoder04",
    author_email="alexcoder04@protonmail.com",
    classifiers=[
        "Intended Audience :: Education",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent"
    ],
    packages=["cs_nds"],
    install_requires=[]
)
